<?php

class EcwidRandomProductsCore {

	// determines whether the "Ecwid shopping cart" core plugin is active
	static $isCorePluginActive = false;
	static $isCorePluginActiveChecked = false;

	function isCorePluginActive() {

		if (!self::$isCorePluginActiveChecked) {

			require_once(ABSPATH . 'wp-admin/includes/plugin.php');
		
			self::$isCorePluginActive = is_plugin_active('ecwid-shopping-cart/ecwid-shopping-cart.php');
			self::$isCorePluginActiveChecked = true;
		}

		return self::$isCorePluginActive;
		
	}

	// determines whether it is possible to show random products
	static $canShowProducts = false;
	static $canShowProductsChecked = false;	

	// ID of page where Ecwid is installed
	static $ecwidPageURL = false;

	function canShowProducts() {

		if (!self::$canShowProductsChecked) {

		        $ecwid_page_id = get_option("ecwid_store_page_id");
		        $page_url = get_page_link($ecwid_page_id);

			if (!empty($page_url) && null != get_page($ecwid_page_id)) {
				self::$canShowProducts = self::isCorePluginActive();
				self::$ecwidPageURL = $page_url;
			}

			self::$canShowProductsChecked = true;
			
		}

		return self::$canShowProducts;
		
	}

	function showStringSetting($name, $description, $value) {
		
		$return = '<tr><th scope="row">' . PHP_EOL;
		$return .= '<label for="' . $name . '">' . $description . '</label>' . PHP_EOL;
		$return .= '</th><td>';
		$return .= '<input id="' . $name . '" type="text" name="' . $name . '" value="' . $value . '" />' . PHP_EOL;
		$return .= '</td></tr>' . PHP_EOL;

		return $return;
	}

	function showWidgetStringSetting($instance, $name, $value, $description) {

		$return = '<p>' . PHP_EOL;
		$return .= '<label for="' . $instance->get_field_name($name) . '">' . $description . '</label>' . PHP_EOL;
		$return .= '<input id="' . $instance->get_field_id($name) . '" type="text" name="' . $instance->get_field_name($name) . '" style="width: 100%;" value="' . $value . '" />' . PHP_EOL;
		$return .= '</p>' . PHP_EOL;

		return $return;
	}

	function showWidgetCheckboxSetting ($instance, $name, $is_checked, $description) {
		
		$checked_statement = ($is_checked == true) ? ' checked' : '';

		$return = '<p>' . PHP_EOL;
		$return .= '<input id="' . $instance->get_field_id($name) . '" type="checkbox" class="checkbox" name="' . $instance->get_field_name($name) . '"' . $checked_statement . ' />' . PHP_EOL;
		$return .= '<label for="' . $instance->get_field_name($name) . '">' . $description . '</label>' . PHP_EOL;
		$return .= '</p>' . PHP_EOL;

		return $return;

	}

	static $config;
	static $isConfigChecked;

	function getConfig() {

		if (!self::$isConfigChecked) {

			global $EcwidProductApi;

			$config = array();
			$config['seoCatalogEnabled'] = ('on' == get_option('ecwid_noscript_seo_catalog'));
			$config['isLocalCurrency'] = ('on' == get_option('ecwid_random_products_use_local_currency'));
			
			if ($config['isLocalCurrency']) {

				$config['currencyPrefix'] = get_option('ecwid_random_products_currency_prefix');
                                $config['currencySuffix'] = get_option('ecwid_random_products_currency_suffix');

			} else {
	
				$profile = $EcwidProductApi->get_profile();
				$config['currencyPrefix'] = $profile['currencyPrefix'];
				$config['currencySuffix'] = $profile['currencySuffix'];

			}
		
			self::$config = $config;
			self::$isConfigChecked = true;
		}


		return self::$config;
	
	}










}
