<?php

// Singletone
class EcwidRandomProductsCoreSettings {

	private static $instance;

	private $ecwidStoreId;
	private $isCorePluginActive = false;
	private $errors = array();
	private $isLocalCurrency;
	private $seoCatalogEnabled;
	private $currency;
	private $ecwidPageUrl = null;
	private $canShowProducts = false;
	private $useCache = true;
	
	public $ecwidStore;

	private function __construct() {

                require_once(ABSPATH . 'wp-admin/includes/plugin.php');

                $this->isCorePluginActive = is_plugin_active('ecwid-shopping-cart/ecwid-shopping-cart.php');

		if (!$this->isCorePluginActive) {

			$errors[] = 'Ecwid shopping cart plugin is not enabled';

		}

		$this->ecwidStoreId = get_ecwid_store_id();
		$this->useCache = ('on' == get_option('ecwid_random_products_use_cache'));

		if ($this->useCache) {

        		$this->ecwidStore = new EcwidRandomProductsCachedEcwidStore();

		} else {

			$this->ecwidStore = new EcwidRandomProductsEcwidStore();

		}

		$this->seoCatalogEnabled = ('on' == get_option('ecwid_noscript_seo_catalog'));
		$this->isLocalCurrency = ('on' == get_option('ecwid_random_products_use_local_currency'));

		$this->currency['local']['prefix'] = get_option('ecwid_random_products_currency_prefix');
                $this->currency['local']['suffix'] = get_option('ecwid_random_products_currency_suffix');

		if ($this->isLocalCurrency) {

        	        $this->currency['prefix'] = $this->currency['local']['prefix'];
                        $this->currency['suffix'] = $this->currency['local']['suffix'];
			

	        } else {

	                $profile = $this->ecwidStore->getProfile();
                	$this->currency['prefix'] = $profile['currencyPrefix'];
        	        $this->currency['suffix'] = $profile['currencySuffix'];

                }

		
	}

	public static function getInstance() {

		if (!isset(self::$instance)) {

			$classname = __CLASS__;
			self::$instance = new $classname();

		}

		return self::$instance;

	}

	public function canShowProducts() {

		$ecwidPageId = get_option("ecwid_store_page_id");
		$pageUrl = get_page_link($ecwidPageId);

		if (!empty($pageUrl) && null != get_page($ecwidPageId)) {

			self::$instance->ecwidPageUrl = $pageUrl;
			self::$instance->canShowProducts = self::$instance->isCorePluginActive;

		} else {

			self::$instance->canShowProducts = false;
			self::$instance->errors[] = 'Ecwid Page in WP was not found';
			
		}

		return self::$instance->canShowProducts;
	
	}

	public function getEcwidPageUrl() {

		return self::$instance->ecwidPageUrl;
	
	}

	public function isSeoCatalogEnabled() {

		return self::$instance->seoCatalogEnabled;

	}

	public function getCurrency() {

		return self::$instance->currency;

	}

	public function isCorePluginActive() {

		return self::$instance->isCorePluginActive;

	}

	public function isLocalCurrency() {

		return self::$instance->isLocalCurrency;	

	}

	public function getStoreId() {
	
		return self::$instance->ecwidStoreId;
		
	}

	public function useCache() {

		return self::$instance->useCache;

	}

}
